##  Exporting Fact Sheet Data as an Excel File
To export fact sheet data, follow these steps:
  1. In the inventory, apply filters to narrow down to the fact sheets that you need to export.
  2. Switch to table view by selecting the As Table icon. Although you can export data in list view as well, we recommend switching to table view. In table view, you can select and add specific fact sheet attributes you want to export, which isn't possible in the list view.
  3. At the top right of the table, click the eye icon. This opens a panel for selecting the fact sheet attributes you want to export. Each selected attribute becomes a column in the table.
  4. From under the Inactive columns section, choose and add the column by clicking the '+' icon. You can also search for a column by its title.
  5. Under the Active columns section, drag and reorder the items as needed. To exclude an existing column, click 'x' next to the item.
  6. From the Inventory Tools drop-down menu, choose Export to Excel. This opens an overlay that provides an overview of your current export and also your export history.
  7. In the export overlay, click Export and then Download.


![Exporting Fact Sheet Data as an Excel File](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio788326b25e184ba1b86102deb3df160b_LowRes.gif)
Exporting Fact Sheet Data as an Excel File
